==> haskell-mustache-2.3.0-86-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mustache
version: 2.3.0
id: mustache-2.3.0-AFhppy4IQ6m5Tlcit8AnRs
key: mustache-2.3.0-AFhppy4IQ6m5Tlcit8AnRs
license: BSD-3-Clause
copyright: (c) 2015,
           2016 Justus Adam
maintainer: dev@justus.science
author: Justus Adam
homepage: https://github.com/JustusAdam/mustache
synopsis: A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.
    .
    Implements the mustache spec version 1.1.3.
    .
    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.
category: Development
abi: 46dd5a8173b6f80a245a248319cf2d14
exposed: True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types
hidden-modules: Text.Mustache.Internal Text.Mustache.Internal.Types
                Paths_mustache
import-dirs: /usr/lib/ghc-8.4.3/site-local/mustache-2.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/mustache-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/mustache-2.3.0
hs-libraries: HSmustache-2.3.0-AFhppy4IQ6m5Tlcit8AnRs
depends:
    base-4.11.1.0 text-1.2.3.0 aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV
    bytestring-0.10.8.2 filepath-1.4.2 parsec-3.1.13.0 mtl-2.2.2
    either-5.0.1-L8KDCAKYhknDGyHit2OsCT
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq directory-1.3.1.5
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl containers-0.5.11.0
    template-haskell-2.13.0.0 th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV=8e4d597de977510ba6167651bfbacc4c
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             either-5.0.1-L8KDCAKYhknDGyHit2OsCT=59690b8ccb7439288b0cd1b7338effaa
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr=3abe31b2134622b7b297c47726ab60c8
haddock-interfaces: /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html: /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mustache-2.3.0-87-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mustache
version: 2.3.0
id: mustache-2.3.0-2hfiUfJvP16F4BGIUGndNn
key: mustache-2.3.0-2hfiUfJvP16F4BGIUGndNn
license: BSD-3-Clause
copyright: (c) 2015,
           2016 Justus Adam
maintainer: dev@justus.science
author: Justus Adam
homepage: https://github.com/JustusAdam/mustache
synopsis: A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.
    .
    Implements the mustache spec version 1.1.3.
    .
    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.
category: Development
abi: b9ddc01e463061443f4b950f96ac4669
exposed: True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types
hidden-modules: Text.Mustache.Internal Text.Mustache.Internal.Types
                Paths_mustache
import-dirs: /usr/lib/ghc-8.4.3/site-local/mustache-2.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/mustache-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/mustache-2.3.0
hs-libraries: HSmustache-2.3.0-2hfiUfJvP16F4BGIUGndNn
depends:
    base-4.11.1.0 text-1.2.3.0 aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL
    bytestring-0.10.8.2 filepath-1.4.2 parsec-3.1.13.0 mtl-2.2.2
    either-5.0.1-F0FA5TpOWP8L5u4g2WGA0o
    unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq directory-1.3.1.5
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl containers-0.5.11.0
    template-haskell-2.13.0.0 th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             either-5.0.1-F0FA5TpOWP8L5u4g2WGA0o=e82328ad6f5e605483eff3b6dc7b9970
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr=3abe31b2134622b7b297c47726ab60c8
haddock-interfaces: /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html: /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
